@@ -328,7 +328,7 @@ class Component:
                 lines = fh.readlines()
                 for i in range(len(lines)):
                     text = lines[i]
-                    if text.find('name') >= 0:
+                    if text[0:5] == 'name:':
                         lines[i] = text.replace(self.name, new_name)
                         break
             with codecs.open(filename, 'w', 'UTF-8') as fh:
