@@ -9,6 +9,7 @@ import shutil
 import git
 
 from .log import *
+from .tools import put_string
 
 
 class simpleProgressBar(git.RemoteProgress):
@@ -68,7 +69,11 @@ class GitRepo:
                     branch = self.repo.create_head(
                         version, self.repo.tags[version])
                     branch.checkout()
-        except:
+            else:
+                origin.pull(version)
+
+        except Exception as ex:
+            # put_string("\nPull %s occur error:(%s)" % (origin.url, str(ex)))
             pass
 
     def fetch(self, remote="origin"):
@@ -83,13 +88,11 @@ class GitRepo:
         try:
             remote.fetch(progress=pullProgressBar())
         except git.GitCommandError as ex:
-            msg = (
-                "Could not fetch remote {remote} ({url}). "
-                "Error: {error}".format(remote=remote.name,
-                                        url=remote.url,
-                                        error=ex)
-            )
-            logger.error(msg)
+            info = str(ex)
+            if info.find('Please make sure you have the correct access rights') > 0:
+                print("Please make sure you have the correct access rights and the repository exists.")
+                print("Use: `yoc addkey`")
+
 
     def import_path(self, path, version):
         files = os.listdir(self.repo.working_dir)
