@@ -326,9 +326,9 @@ class Package(object):
             logger.warn('%s: `version` cannot be empty!' % filename)
             # exit(-1)
 
-        if self.type not in ['solution', 'common', 'board', 'chip']:
+        if self.type not in ['solution', 'common', 'board', 'chip', 'sdk']:
             put_string(
-                '%s: `type` must be "solution" or "common" or "board" or "chip".' % filename)
+                '%s: `type` must be "solution" or "common" or "board" or "chip" or "sdk".' % filename)
             exit(-1)
 
         text = self.hw_info.check(self.type)
@@ -408,7 +408,7 @@ class Package(object):
                 'license', self.license, '# <可选项> 源代码的许可证，要确保所有代码、文件的许可证不冲突。如：MIT，Apache license v2.0，BSD'),
             homepage=self.text_out('homepage', self.homepage),
             type=self.text_out(
-                'type', self.type, '# <必选项> 组件类型，为：solution, chip, board, common'),
+                'type', self.type, '# <必选项> 组件类型，为：solution, chip, board, common, sdk'),
             depends=self.depends_out(),
             source_file=self.fsource_file_out(),
             install=self.install_out('install', self.install),
