@@ -19,10 +19,9 @@ class Variables:
         pass
 
     def set(self, k, v, lower=False):
+        self.vars[k] = v
         if lower:
             self.vars[k.lower()] = v.lower()
-        else:
-            self.vars[k] = v
 
     def get(self, var):
         if var in self.vars:
@@ -66,6 +65,7 @@ class Solution:
         self.libs = []
         self.libpath = []
         self.depend_libs = []
+        self.org_defines = {}
         self.defines = {}
         self.ASFLAGS = []
         self.CCFLAGS = []
@@ -94,6 +94,12 @@ class Solution:
                         put_string("Not found in `%s` components that the current project depends on. " %
                                    self.board_component.hw_info.chip_name)
                         exit(-1)
+                elif self.solution_component.hw_info.chip_name:
+                    self.chip_component = self.components.get(self.solution_component.hw_info.chip_name)
+                    if not self.chip_component:
+                        put_string("Not found in `%s` components that the current project depends on. " %
+                                   self.board_component.hw_info.chip_name)
+                        exit(-1)
                 break
 
         if not self.solution_component:
@@ -136,40 +142,40 @@ class Solution:
         self.components = components
 
         def cpu_set_variable(cpu, arch):
+            def gen_cpu_defs(cpu):
+                c = cpu.upper()
+                c = c.replace('-', '').replace('.', '')
+                c = '__CPU_' + c + '__'
+                return c
+            def gen_arch_defs(arch):
+                a = arch.upper()
+                a = '__ARCH_' + a + '__'
+                return a
+
             self.cpu_name = cpu
             self.variables.set('CPU', cpu.upper(), True)
-            if cpu.lower() == 'rv32emc' or cpu.lower().startswith('e'):
-                if cpu.lower() == 'rv32emc':
-                    self.variables.set('cpu_num', 'rv32')
-                elif cpu.lower() == 'e902':
-                    self.variables.set('cpu_num', 'rv32_16gpr')
-                elif cpu.lower() == 'e906':
-                    self.variables.set('cpu_num', 'rv32_32gpr')
-                elif cpu.lower() == 'e906f':
-                    self.variables.set('cpu_num', 'rv32f_32gpr')
-                elif cpu.lower() == 'e906fd':
-                    self.variables.set('cpu_num', 'rv32fd_32gpr')
-                else:
-                    logger.error("not support rv arch:%s yet" % arch)
-                self.variables.set('arch', 'RISCV', True)
-            # elif cpu.lower() == 'ck803ef':
-            #     self.variables.set('cpu_num', '803ef')
-            #     self.variables.set('ARCH', 'CSKY', True)
+            if arch == '' or arch.upper() == 'CSKY':
+                self.variables.set('cpu_num', cpu_id(cpu))
+                self.variables.set('ARCH', 'CSKY', True)
+            elif arch.upper() == 'ARM':
+                self.variables.set('cpu_num', arm_cpu_id(cpu))
+                self.variables.set('ARCH', arch, True)
+            elif arch.upper() == 'RISCV':
+                self.variables.set('cpu_num', riscv_cpu_id(cpu))
+                self.variables.set('ARCH', arch, True)
             else:
-                if arch == '' or arch.upper() == 'CSKY':
-                    self.variables.set('cpu_num', cpu_id(cpu))
-                    self.variables.set('ARCH', 'CSKY', True)
-                elif arch.upper() == 'ARM':
-                    self.variables.set('cpu_num', arm_cpu_id(cpu))
-                    self.variables.set('ARCH', arch, True)
-                else:
-                    logger.error("not support arch:%s yet" % arch)
+                logger.error("not support arch:%s yet" % arch)
+                exit(-1)
+            # add cpu and arch defines,like __CPU_COTEXM0__ and __ARCH_ARM__
+            self.variables.set(gen_arch_defs(arch), 1)
+            self.variables.set(gen_cpu_defs(cpu), 1)
 
         for component in self.components:
             # defines
             for k, v in component.defconfig.items():
                 self.variables.set(k, v)
                 self.defines[k] = v
+                self.org_defines[k] = v
 
         solution_hw_info = HardwareInfo({})
         for component in [self.chip_component, self.board_component, self.solution_component]:
@@ -273,6 +279,14 @@ class Solution:
             logger.error("not found LD script file, please set ld_script")
             exit(-1)
 
+        # append variables to defines
+        for k, v in self.variables.items():
+            if k.isupper():
+                if k.startswith('__CPU_') or k.startswith('__ARCH_'):
+                    self.defines[k] = v
+                elif not k.startswith('CONFIG'):
+                    self.defines['__AOST_' + k + '__'] = v
+
     def install(self):
         for component in self.components:
             component.install(self.yoc_path)
@@ -344,3 +358,23 @@ def arm_cpu_id(s):
         arr = s.split('-')
         if len(arr) > 1:
             return arr[1]
+
+def riscv_cpu_id(cpu):
+    a = cpu.lower()
+    if a == 'rv32emc':
+        return 'rv32'
+    elif a == 'e902' or a == 'e902m' or a == 'e902t' or a == 'e902mt':
+        return 'rv32_16gpr'
+    elif a == 'e906':
+        return 'rv32_32gpr'
+    elif a == 'e906f':
+        return 'rv32f_32gpr'
+    elif a == 'e906fd':
+        return 'rv32fd_32gpr'
+    elif a == 'c906':
+        return 'rv64_32gpr'
+    elif a == 'c906fd' or a == 'c906v' or a == 'c910' or a == 'c910v':
+        return 'rv64fd_32gpr'
+    else:
+        put_string("%s not support yet." % a)
+        exit(0)
