@@ -43,7 +43,7 @@ Export component to dest directory
 
 
     def component_export(self, component, path):
-        if component.type in ['common', 'chip']:
+        if component.type in ['common', 'chip', 'sdk']:
             p = 'components'
         elif component.type == 'board':
             p = 'boards'
