@@ -18,11 +18,15 @@ class Init(Command):
 Initialize yoc workspace in the current directory.
 """
     def Execute(self, opt, args):
+        conf = Configure()
+        if conf.init:
+            put_string("Workspace is initialized already.")
+            put_string("The workspace is `%s`" % conf.yoc_path)
+            return
         try:
             urlretrieve('https://yoctools.oss-cn-beijing.aliyuncs.com/yoc', '.yoc')
         except:
             pass
         if not os.path.isfile('.yoc'):
-            conf = Configure()
-            conf.yoc_version = 'v7.3.0'
+            conf.yoc_version = 'v7.3-dev'
             conf.save()
