@@ -39,6 +39,10 @@ List all projects; pass '.' to list the project for the cwd.
                      dest='common', action='store_true',
                      help='list all common component')
 
+        p.add_option('-k', '--sdk',
+                     dest='sdk', action='store_true',
+                     help='list all sdk component')
+
         p.add_option('-d', '--depend',
                      dest='depend', action='store_true',
                      help='list component dependencies')
@@ -68,12 +72,12 @@ List all projects; pass '.' to list the project for the cwd.
                 put_string("Can't found component `%s`!" % name)
                 nonexistent_cnt+=1
 
-        show = opt.board or opt.chip or opt.common or opt.solution
+        show = opt.board or opt.chip or opt.common or opt.solution or opt.sdk
         show_cnt = 0
         for c in group:
             if count == 0 or c.name in args:
                 if show:
-                    if (opt.board and c.type == 'board') or (opt.chip and c.type == 'chip') or (opt.common and c.type == 'common') or (opt.solution and c.type == 'solution'):
+                    if (opt.board and c.type == 'board') or (opt.chip and c.type == 'chip') or (opt.common and c.type == 'common') or (opt.solution and c.type == 'solution') or (opt.sdk and c.type == 'sdk'):
                         self.show_depend(yoc, c, opt.depend)
                         show_cnt+=1
                 else:
