@@ -55,26 +55,35 @@ exist in the manifest.
 
     def Execute(self, opt, args):
         yoc = YoC()
-        np = Progress('Fetching projects', len(yoc.components))
+
         if opt.jobs:
             jobs = opt.jobs
         else:
             jobs = 4
-        task_pool = threadpool.ThreadPool(jobs)
 
+        task_pool = threadpool.ThreadPool(jobs)
+        if len(args) > 0:
+            np = Progress('Fetching projects', len(args))
+        else:
+            np = Progress('Fetching projects', len(yoc.components))
         tasks = []
         for component in yoc.components:
+            if len(args) > 0:
+                if component.name not in args:
+                    continue
             component.np = np
             tasks.append(component)
 
         def thread_execture(component):
+            put_string("Syncing %s" % component.name)
             component.np.update()
             git = GitRepo(component.path, component.repo_url)
-            git.fetch()
+            git.pull(component.branch)
 
         requests = threadpool.makeRequests(thread_execture, tasks)
         for req in requests:
             task_pool.putRequest(req)
         task_pool.wait()
+        task_pool.dismissWorkers(jobs, do_join=True)
 
         np.end()
