@@ -33,21 +33,21 @@ Install toolchain.
     def Execute(self, opt, args):
         if os.getuid() != 0:
             put_string(
-                'error: you cannot perform this operation unless you are root. \nsudo ' + ' '.join(sys.argv))
+                'Error: you cannot perform this operation unless you are root. Please input as follow:\nsudo yoc ' + ' '.join(sys.argv[1:]))
             exit(-1)
 
         need_usage = True
         tool = ToolchainYoC()
         if opt.install_all:
-            tool.check_toolchain('csky-abiv2-elf')
-            tool.check_toolchain('riscv64-unknown-elf')
+            tool.check_toolchain('csky-abiv2-elf', 1)
+            tool.check_toolchain('riscv64-unknown-elf', 1)
             need_usage = False
         else:
             if opt.install_csky:
-                tool.check_toolchain('csky-abiv2-elf')
+                tool.check_toolchain('csky-abiv2-elf', 1)
                 need_usage = False
             if opt.install_riscv:
-                tool.check_toolchain('riscv64-unknown-elf')
+                tool.check_toolchain('riscv64-unknown-elf', 1)
                 need_usage = False
         if need_usage:
             self.Usage()
