@@ -49,7 +49,7 @@ def string_len(text):
     R = ''
     if sys.version_info.major == 2:
         if type(text) == str:
-            text = text.encode('utf8').decode('utf8')
+            text = text.decode('utf8')
     for c in text:
         if ord(c) >= 0x4E00 and ord(c) <= 0x9FA5:
             L += 2
